Computes the MSE of the Local Non-Uniformity Correct (LNC) KSG estimator for a given value of the tuning parameter alpha, dimension, neighborhood order, and sample size.
estimate_mse(k = 5, alpha = 0, d = 2, rho = 0, N = 1000,
M = 100, cluster = NULL)Neighborhood order.
Non-uniformity threshold (see details).
Dimension.
Reference correlation (see details).
Sample size.
Number of replications.
A parallel cluster object.
The parameter alpha controls the threshold for the application of the non-uniformity correction to a particular point's neighborhood. Roughly, alpha is the ratio of the PCA aligned neighborhood volume to the rectangular aligned neighborhood volume below which indicates non-uniformity and the correction is applied.
If alpha < 0 then a log scale is assumed; otherwise [0,1] scale is used. alpha > 1 are unacceptable values. A value of alpha = 0 forces no correction and LNC reverts to the KSG estimator.
The reference distribution that is assumed is a mean-zero multivariate normal distribution with a compound-symmetric covariance. The covariance matrix has a single correlation parameter supplied by rho.
# NOT RUN {
estimate_mse(N = 100,M = 2)
# }
Run the code above in your browser using DataLab